@@ -2,7 +2,7 @@ import os
 from cryptography.fernet import Fernet
 
 def generate_key():
-    return Fernet.generate_key()
+    return Fernet.generate_key().decode()
 
 def restore_key(key, entrypted_msg):
     entrypted_msg=entrypted_msg.encode()
